package com.ruoyi.materialType.mapper;

import java.util.List;
import com.ruoyi.materialType.domain.CMaterialType;

/**
 * 物料类别Mapper接口
 *
 * @author ruoyi
 * @date 2024-03-01
 */
public interface CMaterialTypeMapper
{
    /**
     * 查询物料类别
     *
     * @param typeId 物料类别主键
     * @return 物料类别
     */
    public CMaterialType selectCMaterialTypeByTypeId(Long typeId);

    /**
     * 查询物料类别列表
     *
     * @param cMaterialType 物料类别
     * @return 物料类别集合
     */
    public List<CMaterialType> selectCMaterialTypeList(CMaterialType cMaterialType);

    /**
     * 新增物料类别
     *
     * @param cMaterialType 物料类别
     * @return 结果
     */
    public int insertCMaterialType(CMaterialType cMaterialType);

    /**
     * 修改物料类别
     *
     * @param cMaterialType 物料类别
     * @return 结果
     */
    public int updateCMaterialType(CMaterialType cMaterialType);

    /**
     * 删除物料类别
     *
     * @param typeId 物料类别主键
     * @return 结果
     */
    public int deleteCMaterialTypeByTypeId(Long typeId);

    /**
     * 批量删除物料类别
     *
     * @param typeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCMaterialTypeByTypeIds(Long[] typeIds);

    /**
     * 检查物料编码是否存在
     * @param typeNo
     * @return
     */
    CMaterialType checkTypeNoUnique(String typeNo);
}
